


# Nonencm


[![PyPI](https://img.shields.io/pypi/v/nonencm?style=flat-square)](https://pypi.org/project/nonencm/)
[![License](https://img.shields.io/github/license/taurusxin/ncmdump?style=flat-square)](LICENSE)

## 📖 简介

**[pyncm](https://github.com/greats3an/pyncm)** 是一个功能强大的 `ncm` 处理工具。

本项目基于 **pyncm** 与 **noneprompt** 构建的现代化 CLI 界面，提供更便捷的使用体验。


## 🚀 安装与使用

### 方式一：通过 PyPI 安装 (推荐)

如果您熟悉 Python 环境，可以直接通过 pip 安装：

```bash
pip install nonencm
nonencm
```

### 方式二：下载可执行文件

对于没有 Python 环境的用户，可以在 [Releases](../../releases) 页面下载对应系统的可执行文件。Windows 用户下载后直接双击即可。

在终端中运行方法:
- Windows: `win` + `r`，输入 `cmd`，回撤出现黑窗口，拖入 `.exe` 文件，回车运行
- macOS: `open nonencm-macos-vX.X.X`，打开访达找到所在文件夹，右键底部文件夹，选择 `在终端中打开` 输入
    ```bash
    chmod + x nonencm-macos-vX.X.X
    ./nonencm-macos-vX.X.X
    ```

> 使用前请先登录

## 📄 许可证

额别急我研究一下。